fn is_valid_preview_build_label(label: &str) -> boolExpand description
A valid preview build label is a DNS label (1-63 characters of lowercase
ASCII alphanumerics and hyphens, not ending with a hyphen) starting with
PREVIEW_BUILD_LABEL_PREFIX.
fn is_valid_preview_build_label(label: &str) -> boolA valid preview build label is a DNS label (1-63 characters of lowercase
ASCII alphanumerics and hyphens, not ending with a hyphen) starting with
PREVIEW_BUILD_LABEL_PREFIX.